---
id: 20211123214904
title: Find backlinks and list them in card's footer
tags: [backlink, zettel, markdown]
---

# Find backlinks and list them in card's footer

All markdown documents are scanned for links to other markdown documents. When the target is a zettel, then its references section (rendered as card's footer) will be enriched by the links to the referring markdown documents.

The links from `index.md` and `tags.md` are ignored for the sake of brevity.
